# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['vespy']

package_data = \
{'': ['*'], 'vespy': ['certificates/*']}

install_requires = \
['certifi>=2021.5.30,<2022.0.0', 'requests>=2']

entry_points = \
{'console_scripts': ['vespy = vespy.main:run']}

setup_kwargs = {
    'name': 'vespy',
    'version': '0.0.20rc3',
    'description': '"A small utility package',
    'long_description': None,
    'author': 'emher',
    'author_email': 'emher@vestas.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7',
}


setup(**setup_kwargs)



import os
import certifi
import logging

from pathlib import Path

certificate_dir = os.path.join(Path(__file__).parent, "certificates")


def add_certificates():
    path = certifi.where()
    # Get current certificates.
    with open(path, 'r') as f:
        certs = f.readlines()
    with open(path + ".bak", 'w') as f:
        f.writelines(certs)
    # Add Vestas certificates.
    for item in os.listdir(certificate_dir):
        src = os.path.join(certificate_dir, item)
        if os.path.isdir(src):
            continue
        if src[-4:] != ".crt":
            continue
        certs.append("\n")
        certs.append("# Source: " + item)
        certs.append("\n")
        with open(src, 'r') as f:
            cert = f.readlines()
            certs.extend(cert)
    # Write the result.
    with open(path, 'w') as f:
        f.writelines(certs)


def has_certificates():
    with open(certifi.where()) as f_bundle:
        bundle = f_bundle.read()
        for item in os.listdir(certificate_dir):
            src = os.path.join(certificate_dir, item)
            if item.endswith(".crt"):
                with open(src) as cert:
                    if cert.read() not in bundle:
                        return False
    return True


def fix_ssl_error():
    if not has_certificates():
        logging.info("No Vestas certificates found - adding.")
        add_certificates()
